==> custom_pages-v1.12.6.zip: custom_pages/messages/el/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Προσθήκη</strong> στοιχείου {templateName}',
    '<strong>Custom</strong> Pages' => '<strong>Προσαρμοσμένες strong&gt; σελίδες</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Επεξεργασία strong&gt; αποσπάσματος</strong>',
    'Add' => 'Πρόσθεσε',
    'Add a file icon before the title' => 'Προσθέστε ένα εικονίδιο αρχείου πριν από τον τίτλο',
    'Adds plain HTML content to your site.' => 'Προσθέτει απλό περιεχόμενο HTML στον ιστότοπό σας.',
    'Advanced' => 'Προχωρημένο',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Επιτρέπει την προσθήκη σελίδων (markdown, iframe ή links) στον χώρο πλοήγησης',
    'Allows you to add content in MarkDown syntax.' => 'Σας επιτρέπει να προσθέσετε περιεχόμενο σε markdown σύνταξη.',
    'Alternate text' => 'Εναλλακτικό κείμενο',
    'Always make a backup of your view files outside of your production environment!' => 'Πάντα να δημιουργείτε αντίγραφα ασφαλείας των αρχείων προβολής εκτός του περιβάλλοντος παραγωγής σας!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Ένα άδειο επέτρεψε την επιλογή προτύπου θα επιτρέψει όλα τα πρότυπα δοχείων για αυτό το δοχείο.',
    'Back' => 'Πίσω',
    'Back to dashboard' => 'Επιστροφή στο ταμπλό',
    'Back to overview' => 'Επιστροφή στην επισκόπηση',
    'Back to space' => 'Επιστροφή στον χώρο',
    'Configuration' => 'Διαμόρφωση',
    'Content' => 'Περιεχόμενο',
    'Css Class' => 'Css Class',
    'Custom Pages' => 'Προσαρμοσμένες Σελίδες',
    'Custom pages' => 'Προσαρμοσμένες σελίδες',
    'Dashboard' => 'Ταμπλό',
    'Default' => 'Προκαθορισμένο',
    'Default Content' => 'Προεπιλεγμένο περιεχόμενο',
    'Delete' => 'Διαγραφή',
    'Edit' => 'Επεξεργασία',
    'Edit Page' => 'Επεξεργασία σελίδας',
    'Empty' => 'Αδειο',
    'File' => 'Αρχείο',
    'General' => 'Γενικά',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Εικονίδιο',
    'Iframe' => 'Iframe',
    'Insert' => 'Εισαγωγή',
    'Invalid request data!' => 'Μη έγκυρη αίτηση δεδομένων!',
    'Invalid template selection!' => 'Μη έγκυρη επιλογή προτύπου!',
    'Invalid type selection' => 'Μη έγκυρη επιλογή τύπου',
    'Invalid view file selection!' => 'Μη έγκυρη προβολή επιλεγμένου αρχείου!',
    'Link' => 'Σύνδεσμος',
    'MarkDown' => 'Σημειωσετο κάτω',
    'Navigation' => 'Πλοήγηση',
    'On this page you can configure general settings of your custom pages.' => 'Σε αυτήν τη σελίδα μπορείτε να ρυθμίσετε τις γενικές ρυθμίσεις των προσαρμοσμένων σελίδων σας.',
    'Overview' => 'Επισκόπηση',
    'PHP' => 'PHP',
    'Page' => 'Σελίδα',
    'Pages' => 'Σελίδες',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Λάβετε υπόψη ότι οι σελίδες που βασίζονται στο php είναι ευάλωτες σε θέματα ασφάλειας, ειδικά όταν χειρίζονται εισροές χρηστών. Για περισσότερες πληροφορίες, δείτε τις <a href="%7Burl%7D">Yii βέλτιστες πρακτικές ασφαλείας </a>.',
    'Public' => 'Δημόσιο',
    'Reset' => 'Επαναφορά',
    'Settings' => 'Ρυθμίσεις',
    'Show additional file information (size)' => 'Εμφάνιση επιπρόσθετων πληροφοριών αρχείου (μέγεθος)',
    'Snippet' => 'Απόσπασμα',
    'Snippets' => 'Αποσπάσματα',
    'Sort Order' => 'Σειρά ταξινόμησης',
    'Source' => 'Πηγή',
    'Spaces' => 'Χώροι',
    'Style' => 'Στυλ',
    'Style Class' => 'Κατηγορία στυλ',
    'Submit' => 'Υποβολή',
    'Target Url' => 'Στοχευμένει Url',
    'Template' => 'Πρότυπο',
    'Template Layout' => 'Διάταξη προτύπου',
    'Templates' => 'Πρότυπα',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Τα πρότυπα σάς επιτρέπουν να ορίσετε συνδυασμούς θραυσμάτων σελίδας με λειτουργίες επεξεργασίας inline.',
    'This container does not allow any further items!' => 'Αυτό το δοχείο δεν επιτρέπει περαιτέρω στοιχεία!',
    'Title' => 'Τίτλος',
    'Top Navigation' => 'Κορυφαία πλοήγηση',
    'Topics' => 'Θέματα',
    'Type' => 'Τύπος',
    'Upload image' => 'Μεταφόρτωση εικόνας',
    'User Account Menu (Settings)' => 'Μενού λογαριασμού χρήστη (Ρυθμίσεις)',
    'Visibility' => 'Ορατότητα',
    'Will embed the result of a given url as an iframe element.' => 'Θα ενσωματώσει το αποτέλεσμα μιας δοσμένη url ως στοιχείο iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Θα ανακατευθύνει τα αιτήματα σε μια δοσμένη (σχετική ή απόλυτη) διεύθυνση URL.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Με τις σελίδες που βασίζονται σε PHP μπορείτε να δημιουργήσετε προσαρμοσμένες σελίδες μέσω αρχείων προβολής στο σύστημα αρχείων σας. Παρακαλώ ελέγξτε τις ρυθμίσεις της μονάδας για περισσότερες πληροφορίες.',
    'Without adding to navigation (Direct link)' => 'Χωρίς προσθήκη στην πλοήγηση (Άμεσος σύνδεσμος)',
    'You are not allowed to delete default content!' => 'Δεν επιτρέπεται η διαγραφή του προεπιλεγμένου περιεχομένου!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Always' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Custom' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Space' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/el/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Προσθήκη</strong> στοιχείου {templateName}',
    '<strong>Custom</strong> Pages' => '<strong>Προσαρμοσμένες strong&gt; σελίδες</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Επεξεργασία strong&gt; αποσπάσματος</strong>',
    'Add' => 'Πρόσθεσε',
    'Add a file icon before the title' => 'Προσθέστε ένα εικονίδιο αρχείου πριν από τον τίτλο',
    'Adds plain HTML content to your site.' => 'Προσθέτει απλό περιεχόμενο HTML στον ιστότοπό σας.',
    'Advanced' => 'Προχωρημένο',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Επιτρέπει την προσθήκη σελίδων (markdown, iframe ή links) στον χώρο πλοήγησης',
    'Allows you to add content in MarkDown syntax.' => 'Σας επιτρέπει να προσθέσετε περιεχόμενο σε markdown σύνταξη.',
    'Alternate text' => 'Εναλλακτικό κείμενο',
    'Always make a backup of your view files outside of your production environment!' => 'Πάντα να δημιουργείτε αντίγραφα ασφαλείας των αρχείων προβολής εκτός του περιβάλλοντος παραγωγής σας!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Ένα άδειο επέτρεψε την επιλογή προτύπου θα επιτρέψει όλα τα πρότυπα δοχείων για αυτό το δοχείο.',
    'Back' => 'Πίσω',
    'Back to dashboard' => 'Επιστροφή στο ταμπλό',
    'Back to overview' => 'Επιστροφή στην επισκόπηση',
    'Back to space' => 'Επιστροφή στον χώρο',
    'Configuration' => 'Διαμόρφωση',
    'Content' => 'Περιεχόμενο',
    'Css Class' => 'Css Class',
    'Custom Pages' => 'Προσαρμοσμένες Σελίδες',
    'Custom pages' => 'Προσαρμοσμένες σελίδες',
    'Dashboard' => 'Ταμπλό',
    'Default' => 'Προκαθορισμένο',
    'Default Content' => 'Προεπιλεγμένο περιεχόμενο',
    'Delete' => 'Διαγραφή',
    'Edit' => 'Επεξεργασία',
    'Edit Page' => 'Επεξεργασία σελίδας',
    'Empty' => 'Αδειο',
    'File' => 'Αρχείο',
    'General' => 'Γενικά',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Εικονίδιο',
    'Iframe' => 'Iframe',
    'Insert' => 'Εισαγωγή',
    'Invalid request data!' => 'Μη έγκυρη αίτηση δεδομένων!',
    'Invalid template selection!' => 'Μη έγκυρη επιλογή προτύπου!',
    'Invalid type selection' => 'Μη έγκυρη επιλογή τύπου',
    'Invalid view file selection!' => 'Μη έγκυρη προβολή επιλεγμένου αρχείου!',
    'Link' => 'Σύνδεσμος',
    'MarkDown' => 'Σημειωσετο κάτω',
    'Navigation' => 'Πλοήγηση',
    'On this page you can configure general settings of your custom pages.' => 'Σε αυτήν τη σελίδα μπορείτε να ρυθμίσετε τις γενικές ρυθμίσεις των προσαρμοσμένων σελίδων σας.',
    'Overview' => 'Επισκόπηση',
    'PHP' => 'PHP',
    'Page' => 'Σελίδα',
    'Pages' => 'Σελίδες',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Λάβετε υπόψη ότι οι σελίδες που βασίζονται στο php είναι ευάλωτες σε θέματα ασφάλειας, ειδικά όταν χειρίζονται εισροές χρηστών. Για περισσότερες πληροφορίες, δείτε τις <a href="%7Burl%7D">Yii βέλτιστες πρακτικές ασφαλείας </a>.',
    'Public' => 'Δημόσιο',
    'Reset' => 'Επαναφορά',
    'Settings' => 'Ρυθμίσεις',
    'Show additional file information (size)' => 'Εμφάνιση επιπρόσθετων πληροφοριών αρχείου (μέγεθος)',
    'Snippet' => 'Απόσπασμα',
    'Snippets' => 'Αποσπάσματα',
    'Sort Order' => 'Σειρά ταξινόμησης',
    'Source' => 'Πηγή',
    'Spaces' => 'Χώροι',
    'Style' => 'Στυλ',
    'Style Class' => 'Κατηγορία στυλ',
    'Submit' => 'Υποβολή',
    'Target Url' => 'Στοχευμένει Url',
    'Template' => 'Πρότυπο',
    'Template Layout' => 'Διάταξη προτύπου',
    'Templates' => 'Πρότυπα',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Τα πρότυπα σάς επιτρέπουν να ορίσετε συνδυασμούς θραυσμάτων σελίδας με λειτουργίες επεξεργασίας inline.',
    'This container does not allow any further items!' => 'Αυτό το δοχείο δεν επιτρέπει περαιτέρω στοιχεία!',
    'Title' => 'Τίτλος',
    'Top Navigation' => 'Κορυφαία πλοήγηση',
    'Topics' => 'Θέματα',
    'Type' => 'Τύπος',
    'Upload image' => 'Μεταφόρτωση εικόνας',
    'User Account Menu (Settings)' => 'Μενού λογαριασμού χρήστη (Ρυθμίσεις)',
    'Visibility' => 'Ορατότητα',
    'Will embed the result of a given url as an iframe element.' => 'Θα ενσωματώσει το αποτέλεσμα μιας δοσμένη url ως στοιχείο iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Θα ανακατευθύνει τα αιτήματα σε μια δοσμένη (σχετική ή απόλυτη) διεύθυνση URL.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Με τις σελίδες που βασίζονται σε PHP μπορείτε να δημιουργήσετε προσαρμοσμένες σελίδες μέσω αρχείων προβολής στο σύστημα αρχείων σας. Παρακαλώ ελέγξτε τις ρυθμίσεις της μονάδας για περισσότερες πληροφορίες.',
    'Without adding to navigation (Direct link)' => 'Χωρίς προσθήκη στην πλοήγηση (Άμεσος σύνδεσμος)',
    'You are not allowed to delete default content!' => 'Δεν επιτρέπεται η διαγραφή του προεπιλεγμένου περιεχομένου!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Custom' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Sorting' => '',
    'Space' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
